TikTok
------

If your app is still in testing/development please complete the Integration Assessment for Unreleased Apps instead, and submit it to be reviewed by our team.

How to Submit a Integration Assessment for Unreleased App:

1. Sign up for a TikTok for Developer account here: https://developers.tiktok.com/
2. After logging into your account select the icon in the upper right hand corner and select "Manage Apps"
3. Select "Connect an app" and fill out the app review. Do not submit the application at this time
4. Complete your Integration Assessment for Unreleased App here: https://developers.tiktok.com/application/unreleased-app-integration
5. Our team will notify you via email if you have been approved.
6. Upon approval, please submit your TikTok for Developer App Review, and sure to include the products and scopes that you are requesting access to.
7. Receive an email confirmation that your TikTok for Developer App Review has been approved and you now have access to the APIs and scopes.


Development callback URL

TikTok only support https callback url, so you need to use ngrok to create a https tunnel to your localhost. In
addition, the url needs to be fixed (paid) because it is taked into account by TikTok after submission and upon
validation by TikTok.
